#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Definition sof the binding pocket for the PDB id: x0161 and 6lu7.
"""
r_6lu7 = {
  "A": {
    "boxcenter": [
      -13.07,
      12.58,
      67.15
    ],
    "boxsize": [
      22.5,
      23.625,
      23.25
    ]
  }
}
r_x0161 = {
  "A": {
    "boxcenter": [
      12.11,
      1.84,
      23.56
    ],
    "boxsize": [
      22.5,
      22.5,
      22.5
    ]
  }
}